diff --git src/bp-core/bp-core-actions.php src/bp-core/bp-core-actions.php
index caf628b97..cce575de3 100644
--- src/bp-core/bp-core-actions.php
+++ src/bp-core/bp-core-actions.php
@@ -119,6 +119,9 @@ add_action( 'bp_after_setup_theme', 'bp_check_theme_template_pack_dependency',
 add_action( 'bp_after_setup_theme', 'bp_load_theme_functions',                    1  );
 add_action( 'bp_after_setup_theme', 'bp_register_theme_compat_default_features',  10 );
 
+// Adds a new hook to be sure to enqueue scripts when `is_buddypress()` is true.
+add_action( 'bp_enqueue_scripts', 'bp_enqueue_community_scripts' );
+
 // Load the admin.
 if ( is_admin() ) {
 	add_action( 'bp_loaded', 'bp_admin' );
diff --git src/bp-core/bp-core-cssjs.php src/bp-core/bp-core-cssjs.php
index 56b6c9f09..eeeadb8d4 100644
--- src/bp-core/bp-core-cssjs.php
+++ src/bp-core/bp-core-cssjs.php
@@ -185,7 +185,7 @@ function bp_core_confirmation_js() {
 	) );
 
 }
-add_action( 'bp_enqueue_scripts',       'bp_core_confirmation_js' );
+add_action( 'bp_enqueue_community_scripts', 'bp_core_confirmation_js', 1 );
 add_action( 'bp_admin_enqueue_scripts', 'bp_core_confirmation_js' );
 
 /**
@@ -206,7 +206,7 @@ function bp_core_avatar_scripts() {
 	add_action( 'bp_after_group_admin_content',           'bp_avatar_template_check' );
 	add_action( 'bp_after_group_avatar_creation_step',    'bp_avatar_template_check' );
 }
-add_action( 'bp_enqueue_scripts', 'bp_core_avatar_scripts' );
+add_action( 'bp_enqueue_community_scripts', 'bp_core_avatar_scripts' );
 
 /**
  * Enqueues the css and js required by the Cover Image UI.
@@ -221,7 +221,7 @@ function bp_core_cover_image_scripts() {
 	// Enqueue the Attachments scripts for the Cover Image UI.
 	bp_attachments_enqueue_scripts( 'BP_Attachment_Cover_Image' );
 }
-add_action( 'bp_enqueue_scripts', 'bp_core_cover_image_scripts' );
+add_action( 'bp_enqueue_community_scripts', 'bp_core_cover_image_scripts' );
 
 /**
  * Enqueues jCrop library and hooks BP's custom cropper JS.
@@ -522,7 +522,7 @@ function bp_add_cover_image_inline_css( $return = false ) {
 		}
 	}
 }
-add_action( 'bp_enqueue_scripts', 'bp_add_cover_image_inline_css', 11 );
+add_action( 'bp_enqueue_community_scripts', 'bp_add_cover_image_inline_css', 11 );
 
 /**
  * Enqueues livestamp.js on BuddyPress pages.
@@ -530,13 +530,9 @@ add_action( 'bp_enqueue_scripts', 'bp_add_cover_image_inline_css', 11 );
  * @since 2.7.0
  */
 function bp_core_add_livestamp() {
-	if ( ! is_buddypress() ) {
-		return;
-	}
-
 	bp_core_enqueue_livestamp();
 }
-add_action( 'bp_enqueue_scripts', 'bp_core_add_livestamp' );
+add_action( 'bp_enqueue_community_scripts', 'bp_core_add_livestamp' );
 
 /**
  * Enqueue and localize livestamp.js script.
diff --git src/bp-templates/bp-legacy/buddypress-functions.php src/bp-templates/bp-legacy/buddypress-functions.php
index dd9ca60bd..76d6d3108 100644
--- src/bp-templates/bp-legacy/buddypress-functions.php
+++ src/bp-templates/bp-legacy/buddypress-functions.php
@@ -80,9 +80,9 @@ class BP_Legacy extends BP_Theme_Compat {
 
 		/** Scripts ***********************************************************/
 
-		add_action( 'bp_enqueue_scripts', array( $this, 'enqueue_styles'   ) ); // Enqueue theme CSS
-		add_action( 'bp_enqueue_scripts', array( $this, 'enqueue_scripts'  ) ); // Enqueue theme JS
-		add_filter( 'bp_enqueue_scripts', array( $this, 'localize_scripts' ) ); // Enqueue theme script localization
+		add_action( 'bp_enqueue_community_scripts', array( $this, 'enqueue_styles'   ) ); // Enqueue theme CSS
+		add_action( 'bp_enqueue_community_scripts', array( $this, 'enqueue_scripts'  ) ); // Enqueue theme JS
+		add_action( 'bp_enqueue_community_scripts', array( $this, 'localize_scripts' ) ); // Enqueue theme script localization
 
 		/** Body no-js Class **************************************************/
 
diff --git src/bp-templates/bp-nouveau/buddypress-functions.php src/bp-templates/bp-nouveau/buddypress-functions.php
index fac582cab..685e2b93f 100644
--- src/bp-templates/bp-nouveau/buddypress-functions.php
+++ src/bp-templates/bp-nouveau/buddypress-functions.php
@@ -178,7 +178,7 @@ class BP_Nouveau extends BP_Theme_Compat {
 
 		// Scripts & Styles.
 		$registration_params = array(
-			'hook'     => 'bp_enqueue_scripts',
+			'hook'     => 'bp_enqueue_community_scripts',
 			'priority' => 2,
 		);
 
@@ -195,14 +195,14 @@ class BP_Nouveau extends BP_Theme_Compat {
 		add_action( $registration_params['hook'], array( $this, 'register_scripts' ), $registration_params['priority'] );
 
 		// Enqueue theme CSS.
-		add_action( 'bp_enqueue_scripts', array( $this, 'enqueue_styles' ) );
+		add_action( 'bp_enqueue_community_scripts', array( $this, 'enqueue_styles' ) );
 
 		// Enqueue theme JS.
-		add_action( 'bp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
+		add_action( 'bp_enqueue_community_scripts', array( $this, 'enqueue_scripts' ) );
 
 		// Enqueue theme script localization.
-		add_filter( 'bp_enqueue_scripts', array( $this, 'localize_scripts' ) );
-		remove_action( 'bp_enqueue_scripts', 'bp_core_confirmation_js' );
+		add_action( 'bp_enqueue_community_scripts', array( $this, 'localize_scripts' ) );
+		remove_action( 'bp_enqueue_community_scripts', 'bp_core_confirmation_js', 1 );
 
 		// Body no-js class.
 		add_filter( 'body_class', array( $this, 'add_nojs_body_class' ), 20, 1 );

diff --git src/bp-core/bp-core-dependency.php src/bp-core/bp-core-dependency.php
index 91d2566b3..5e3df5429 100644
--- src/bp-core/bp-core-dependency.php
+++ src/bp-core/bp-core-dependency.php
@@ -499,21 +499,42 @@ function bp_enqueue_scripts() {
 }
 
 /**
- * Fires the 'bp_enqueue_embed_scripts' action in the <head> for BP oEmbeds.
+ * Fires an action hook to enqueue scripts and styles for specific BuddyPress contexts.
  *
- * @since 2.6.0
+ * @since 11.0.0
+ *
+ * @param string $context The specific BuddyPress context. Supported values are `embed` and `community`.
+ *                        Default: `embed`.
  */
-function bp_enqueue_embed_scripts() {
+function bp_enqueue_context_scripts( $context = 'embed' ) {
 	if ( ! is_buddypress() ) {
 		return;
 	}
 
 	/**
 	 * Enqueue CSS and JS files for BuddyPress embeds.
 	 *
-	 * @since 2.6.0
+	 * @since 11.0.0
 	 */
-	do_action( 'bp_enqueue_embed_scripts' );
+	do_action( "bp_enqueue_{$context}_scripts" );
+}
+
+/**
+ * Fires the 'bp_enqueue_embed_scripts' action in the <head> for BP oEmbeds.
+ *
+ * @since 2.6.0
+ */
+function bp_enqueue_embed_scripts() {
+	return bp_enqueue_context_scripts( 'embed' );
+}
+
+/**
+ * Fires the  `bp_enqueue_community_scripts` action for Template packs scripts and styles.
+ *
+ * @since 11.0.0
+ */
+function bp_enqueue_community_scripts() {
+	return bp_enqueue_context_scripts( 'community' );
 }
 
 /**
@@ -499,21 +499,42 @@ function bp_enqueue_scripts() {
 
 	/**
-	 * Enqueue CSS and JS files for BuddyPress embeds.
+	 * Enqueue CSS and JS files for a specific BuddyPress context.
 	 *